<?php
$translations = array(
	'General_Locale' => 'ja_JP.UTF-8',
	'General_TranslatorName' => 'Takafumi/Drupal Japan - http://drupal.jp',
	'General_TranslatorEmail' => 'imagine@drupal.jp',
	'General_EnglishLanguageName' => 'Japanese',
	'General_OriginalLanguageName' => '日本語',
	'General_HelloUser' => 'こんにちは、%sさん！',
	'General_OpenSourceWebAnalytics' => 'オープンソースウェブ解析',
	'General_Dashboard' => 'ダッシュボード',
	'General_DashboardForASpecificWebsite' => '特定ウェブサイトのダッシュボード',
	'General_MultiSitesSummary' => '全ウェブサイト',
	'General_AllWebsitesDashboard' => '全ウェブサイトのダッシュボード',
	'General_API' => 'API',
	'General_Widgets' => 'ウィジェット',
	'General_Settings' => '設定',
	'General_GiveUsYourFeedback' => 'フィードバックをお願いします！',
	'General_Unknown' => '不明',
	'General_Required' => '%s は必須です',
	'General_NotValid' => '%s は有効ではありません',
	'General_Id' => 'ID',
	'General_Error' => 'エラー',
	'General_Warning' => '警告',
	'General_BackToHomepage' => 'Piwik ホームページに戻る',
	'General_Yes' => 'はい',
	'General_No' => 'いいえ',
	'General_Delete' => '削除',
	'General_Report' => 'リポート',
	'General_Edit' => '編集',
	'General_Download' => 'ダウンロード',
	'General_Ok' => 'OK',
	'General_Close' => '閉じる',
	'General_OrCancel' => 'または %s キャンセル %s',
	'General_Logout' => 'ログアウト',
	'General_Username' => 'ユーザー名',
	'General_Description' => '説明',
	'General_Done' => '完了',
	'General_Name' => '名前',
	'General_Value' => '値',
	'General_Details' => '詳細',
	'General_Default' => 'デフォルト',
	'General_Date' => '日付',
	'General_Period' => '期間',
	'General_ChooseDate' => '日付を選択',
	'General_Today' => '今日',
	'General_Yesterday' => '昨日',
	'General_CurrentWeek' => '今週',
	'General_CurrentMonth' => '今月',
	'General_CurrentYear' => '今年',
	'General_DateRange' => '期間：',
	'General_LoadingData' => 'データ読み込み中...',
	'General_Loading_js' => '読み込み中...',
	'General_GoTo' => '%s へ',
	'General_Next' => '次へ',
	'General_Previous' => '前へ',
	'General_Search' => '検索',
	'General_Others' => 'その他',
	'General_Table' => 'テーブル',
	'General_Piechart' => '円グラフ',
	'General_TagCloud' => 'タグクラウド',
	'General_VBarGraph' => '垂直棒グラフ',
	'General_OpenInNewWindow_js' => '新しいウィンドウで開く',
	'General_SaveImageOnYourComputer_js' => '画像を保存するには、画像を右クリックして "名前を付けて画像を保存" を選択します',
	'General_Refresh' => 'ページの再読み込み',
	'General_Visitors' => 'ビジター',
	'General_ExportThisReport' => '他のフォーマットでこのデータセットをエクスポートする',
	'General_ExportAsImage_js' => '画像としてエクスポートする',
	'General_Export' => 'エクスポート',
	'General_YourChangesHaveBeenSaved' => '変更は保存されました。',
	'General_ErrorRequest' => 'リクエスト中に問題がありました。 再試行してください。',
	'General_ColumnNbUniqVisitors' => 'ユニークビジター数',
	'General_ColumnNbVisits' => 'ビジット',
	'General_ColumnPercentageVisits' => '% ビジット',
	'General_ColumnNbActions' => 'アクション',
	'General_ColumnMaxActions' => '1ビジットでの最大アクション数',
	'General_ColumnSumVisitLength' => 'ビジターの総滞在時間（秒単位）',
	'General_ColumnLabel' => 'ラベル',
	'General_ColumnConversionRate' => 'コンバージョン率',
	'General_ColumnActionsPerVisit' => 'ビジット単位のアクション数',
	'General_VisitDuration' => 'ビジットの平均継続時間（秒単位）',
	'General_ColumnAvgTimeOnSite' => '平均ウェブサイト滞在時間',
	'General_ColumnBounceRate' => 'バウンス率',
	'General_ColumnExitRate' => '退出率',
	'General_ColumnPageviews' => 'ページビュー',
	'General_ColumnUniquePageviews' => 'ユニークページビュー',
	'General_ColumnBounces' => 'バウンス',
	'General_ColumnEntrances' => '入口（ブラウズ開始）',
	'General_ColumnExits' => '出口（ブラウズ終了）',
	'General_ColumnAverageTimeOnPage' => '平均ページ滞在時間',
	'General_ColumnValuePerVisit' => 'ビジット単位の価値',
	'General_ColumnVisitsWithConversions' => 'コンバージョン付きビジット',
	'General_YearsDays' => '%1$s 年 %2$s 日',
	'General_DaysHours' => '%1$s 日 %2$s 時間',
	'General_HoursMinutes' => '%1$s 時間 %2$s 分',
	'General_MinutesSeconds' => '%1$s 分 %2$s 秒',
	'General_Seconds' => '%s 秒',
	'General_Save' => '保存',
	'General_ForExampleShort' => '例：',
	'General_YouMustBeLoggedIn' => 'この機能にアクセスするにはログインする必要があります。',
	'General_Website' => 'ウェブサイト',
	'General_GeneralSettings' => '全般の設定',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'リポートがブラウザで表示されたときをトリガーとする Piwik アーカイブ処理を許可',
	'General_ArchivingInlineHelp' => '比較的トラフィックの高いウェブサイトでは、ブラウザでの表示をトリガーとする Piwik アーカイブ処理を無効にすることをお勧めします。 代わりに、1時間ごとに Piwik リポートを処理する cron ジョブをセットアップすることをお勧めします。',
	'General_ArchivingTriggerDescription' => '比較的トラフィックの高いウェブサイトに推奨します。 自動リポート処理には %scron ジョブのセットアップ%sが必要となります。',
	'General_SeeTheOfficialDocumentationForMoreInformation' => '詳細については、%s公式ドキュメント%sを参照してください。',
	'General_NSeconds' => '%s 秒',
	'General_SmallTrafficYouCanLeaveDefault' => 'トラフィックの少ないウェブサイトでは、デフォルトの %s 秒の設定で、リアルタイムにすべてのリポートにアクセス可能です。',
	'General_MediumToHighTrafficItIsRecommendedTo' => '比較的トラフィックの高いウェブサイトでは、今日のリポートの処理間隔を 30分（%s 秒） または 1時間（%s 秒） に設定することをお勧めします。',
	'General_RequiresFlash' => 'Piwik でのグラフの表示には Flash が必要となります',
	'General_GraphHelp' => 'Piwik でのグラフ表示の詳細です。',
	'General_NoDataForGraph' => 'このグラフのデータはありません。',
	'General_NoDataForTagCloud' => 'このタグクラウドのデータはありません。',
	'General_DisplaySimpleTable' => 'シンプルなテーブル表示',
	'General_DisplayTableWithMoreMetrics' => 'より多くのメトリックを含むテーブル表示',
	'General_DisplayTableWithGoalMetrics' => '目標メトリックを含むテーブル表示',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s は共同プロジェクトです。%3$sあなたが Piwik のファンであれば支援することができます！ 詳細は %4$s How to participate in Piwik?%5$s を確認してください。',
	'General_YouAreViewingDemoShortMessage' => '現在、Piwik のデモを表示しています',
	'General_DownloadFullVersion' => 'フルバージョンを%1$sダウンロード%2$s！ %3$s を確認してください',
	'General_NewUpdatePiwikX' => '新しいアップデート： Piwik %s',
	'General_AboutPiwikX' => 'Piwik %s について',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s が利用可能です。 %2$s今すぐアップデートしてください！%3$s（%4$s変更点%5$sを参照）。',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s が利用可能です。 サイト管理者に通知してください。',
	'General_NewReportsWillBeProcessedByCron' => 'Piwik アーカイブ処理がブラウザによる表示をトリガーとしない場合、新しいリポートは crontab によって処理されます。',
	'General_ReportsWillBeProcessedAtMostEveryHour' => '従って、リポートは1時間ごとに処理されます。',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'より早くアーカイブ処理を行いたい場合は、cron がより頻繁に実行されるように crontab を設定します。',
	'General_BackToPiwik' => 'Piwik へ戻る',
	'General_ShortMonth_1' => '1月',
	'General_ShortMonth_2' => '2月',
	'General_ShortMonth_3' => '3月',
	'General_ShortMonth_4' => '4月',
	'General_ShortMonth_5' => '5月',
	'General_ShortMonth_6' => '6月',
	'General_ShortMonth_7' => '7月',
	'General_ShortMonth_8' => '8月',
	'General_ShortMonth_9' => '9月',
	'General_ShortMonth_10' => '10月',
	'General_ShortMonth_11' => '11月',
	'General_ShortMonth_12' => '12月',
	'General_LongMonth_1' => '1月',
	'General_LongMonth_2' => '2月',
	'General_LongMonth_3' => '3月',
	'General_LongMonth_4' => '4月',
	'General_LongMonth_5' => '5月',
	'General_LongMonth_6' => '6月',
	'General_LongMonth_7' => '7月',
	'General_LongMonth_8' => '8月',
	'General_LongMonth_9' => '9月',
	'General_LongMonth_10' => '10月',
	'General_LongMonth_11' => '11月',
	'General_LongMonth_12' => '12月',
	'General_ShortDay_1' => '月',
	'General_ShortDay_2' => '火',
	'General_ShortDay_3' => '水',
	'General_ShortDay_4' => '木',
	'General_ShortDay_5' => '金',
	'General_ShortDay_6' => '土',
	'General_ShortDay_7' => '日',
	'General_LongDay_1' => '月曜日',
	'General_LongDay_2' => '火曜日',
	'General_LongDay_3' => '水曜日',
	'General_LongDay_4' => '木曜日',
	'General_LongDay_5' => '金曜日',
	'General_LongDay_6' => '土曜日',
	'General_LongDay_7' => '日曜日',
	'General_Daily' => '毎日',
	'General_Weekly' => '毎週',
	'General_Monthly' => '毎月',
	'General_ConfigFileIsNotWritable' => 'Piwik 設定ファイル %s が書き込み可能ではないため、いくつかの変更が保存されない可能性があります。%s設定ファイルのパーミッションを書き込み可能に変更してください。',
	'General_ExceptionDatabaseVersion' => '%1$s のバージョンが %2$s ですが、Piwik には少なくとも %3$s が必要となります。',
	'General_ExceptionIncompatibleClientServerVersions' => '%1$s クライアントのバージョンが %2$s であり、サーバーバージョン %3$s と互換性がありません。',
	'General_ExceptionMissingFile' => '不足ファイル： %s',
	'General_ExceptionFilesizeMismatch' => 'ファイルサイズの不整合： %1$s （想定サイズ： %2$s、実サイズ： %3$s）',
	'General_ExceptionFileIntegrity' => '整合性チェックの失敗： %s',
	'General_ExceptionNonceMismatch' => 'このフォームのセキュリティトークンを検証することができませんでした。',
	'General_PleaseSpecifyValue' => '\'%s\' の値を指定してください。',
	'General_ExceptionMethodNotFound' => 'メソッド \'%s\' は、存在しないか、モジュール \'%s\' で利用可能ではありません。',
	'General_ExceptionInvalidRendererFormat' => '出力書式 \'%s\' は有効ではありません。 次のいずれかを試してください： %s',
	'General_ExceptionInvalidPeriod' => '期間 \'%s\' はサポートされていません。 代わりに次のいずれかを試してください： %s',
	'General_ExceptionInvalidDateRange' => '日付 \'%s\' は正しい日付の範囲ではありません。 日付は次の書式である必要があります： %s',
	'General_ExceptionGoalNotFound' => 'goal id = %s が見つかりませんでした。',
	'General_ExceptionUndeletableFile' => '%s が削除できませんでした',
	'General_ExceptionPrivilege' => 'このリソースには %s アクセス権が必要なため、アクセスすることはできません。',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'このリソースには少なくとも1つのウェブサイト用の %s アクセス権が必要なため、アクセスすることはできません。',
	'General_ExceptionPrivilegeAccessWebsite' => 'このリソースには website id = %d 用の %s アクセス権が必要なため、アクセスすることはできません。',
	'General_ExceptionInvalidArchiveTimeToLive' => '今日のアーカイブの有効期限は 0 より大きい秒数である必要があります',
	'General_ExceptionConfigurationFileNotFound' => '設定ファイル {%s} が見つかりませんでした',
	'General_ExceptionUnreadableFileDisabledMethod' => '設定ファイル {%s} を読み込むことができませんでした。 サーバーで %s が無効化されている可能性があります。',
	'General_ExceptionInvalidToken' => 'トークンが有効ではありません。',
	'General_ExceptionInvalidDateFormat' => '有効な日付の書式： %s または %s 関数でサポートされる任意のキーワード（詳細は %s を参照）',
	'General_ExceptionLanguageFileNotFound' => '言語ファイル \'%s\' が見つかりませんでした',
	'General_WarningFileIntegritySkipped' => '開発環境が検出されたため、ファイルの整合性チェックは省略されました。',
	'General_WarningFileIntegrityNoManifest' => 'manifest.inc.php が不足しているため、ファイルの整合性チェックを実行することができませんでした。',
	'General_WarningFileIntegrityNoMd5file' => 'md5_file() 関数が存在しないため、ファイルの整合性チェックを完了することができませんでした。',
	'General_FileIntegrityWarningExplanation' => 'ファイルの整合性チェックが失敗し、いくつかのエラーが報告されました。 これはほとんどの場合、ファイルが不完全であるか、いくつかの Piwik ファイルのアップロードに失敗しています。 すべての Piwik ファイルをバイナリモードで再アップロードして、エラーが表示されなくなるまでページをリフレッシュする必要があります。',
	'General_UseSMTPServerForEmail' => 'メール送信に SMTP サーバを使用',
	'General_SmtpServerAddress' => 'SMTP のサーバアドレス',
	'General_SmtpPort' => 'SMTP のポート番号',
	'General_AuthenticationMethodSmtp' => 'SMTP の認証方法',
	'General_SmtpUsername' => 'SMTP のユーザー名',
	'General_SmtpPassword' => 'SMTP のパスワード',
	'General_SmtpEncryption' => 'SMTP の暗号化',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'ローカルの mail() 関数の代わりにメールサーバー経由でメールを送信したい場合は、"はい" を選択します',
	'General_OptionalSmtpPort' => 'オプションです。 非暗号化と TLS SMTP では 25 が、SSL SMTP では 465 がデフォルトになります。',
	'General_OnlyUsedIfUserPwdIsSet' => 'ユーザー名／パスワードが設定されている場合にのみ使用されます。 どの方法を使用すべきかがよくわからない場合は、プロバイダにお問い合わせください。',
	'General_OnlyEnterIfRequired' => 'SMTP サーバがユーザー名を必要とする場合にのみ入力します。',
	'General_OnlyEnterIfRequiredPassword' => 'SMTP サーバがパスワードを必要とする場合にのみ入力します。',
	'General_WarningPasswordStored' => '%s警告：%s このパスワードは設定ファイルに保存されます。 この設定ファイルにアクセス可能な人であれば、パスワードを見られる可能性があることに注意してください。',
	'General_EncryptedSmtpTransport' => 'SMTP サーバーで必要となる、トランスポートレイヤーの暗号を入力します。',
	'General_InvalidResponse' => '受信したデータが無効です。',
	'General_ChooseLanguage' => '言語を選択',
	'General_ChoosePeriod' => '期間を選択',
	'General_ChooseWebsite' => 'ウェブサイトを選択',
	'General_Language' => '言語',
	'General_PleaseUpdatePiwik' => 'Piwik を更新してください',
	'General_RequestTimedOut' => '%s へのデータリクエストがタイムアウトしました。 再試行してください。',
	'Actions_PluginDescription' => 'ページビュー、外部リンク、ダウンロードについてリポートします。 外部リンクとダウンロードのトラッキングは自動です！',
	'Actions_Actions' => 'アクション',
	'Actions_SubmenuPages' => 'ページ',
	'Actions_SubmenuPagesEntry' => '入口ページ',
	'Actions_SubmenuPagesExit' => '出口ページ',
	'Actions_SubmenuPageTitles' => 'ページタイトル',
	'Actions_SubmenuOutlinks' => '外部リンク',
	'Actions_SubmenuDownloads' => 'ダウンロード',
	'Actions_ColumnClicks' => 'クリック数',
	'Actions_ColumnUniqueClicks' => 'ユニーククリック数',
	'Actions_ColumnDownloads' => 'ダウンロード数',
	'Actions_ColumnUniqueDownloads' => 'ユニークダウンロード数',
	'Actions_ColumnPageName' => 'ページ名',
	'Actions_ColumnPageURL' => 'ページ URL',
	'Actions_ColumnClickedURL' => 'クリックされた URL',
	'Actions_ColumnDownloadURL' => 'ダウンロード URL',
	'AnonymizeIP_PluginDescription' => 'ローカルプライバシー規則やガイドラインに応じて、ビジターの IP アドレスの最終バイトを匿名化します。',
	'API_PluginDescription' => 'Piwik のすべてのデータはシンプルな API 経由で利用可能です。 このプラグインは、xml、json、php、csv 等にウェブ解析データを得るためにコールすることができる、ウェブサービスのエントリーポイントです。',
	'API_QuickDocumentationTitle' => 'API クイックドキュメント',
	'API_GenerateVisits' => '今日のデータがない場合は、%s プラグインを使用して、はじめに若干のデータを生成することができます。 これを行うには、%s プラグインを有効にし、管理エリアで \'ビジタージェネレータ\' メニューをクリックします。',
	'API_MoreInformation' => 'Piwik API の詳細については、%sIntroduction to Piwik API%s や %sPiwik API Reference%s を参照してください。',
	'API_UserAuthentication' => 'ユーザー認証',
	'API_UsingTokenAuth' => '%sスクリプト（crontab 等）でリクエストデータを得たい場合%sは、API をコールする URL（認証が必要）にパラメータ %s を付加する必要があります。',
	'API_KeepTokenSecret' => 'token_auth は、ログイン名とパスワードのように秘密にし、%s絶対に共有しないでください%s！',
	'API_LoadedAPIs' => '%s API が正常に読み込まれました',
	'CoreAdminHome_PluginDescription' => 'Piwik の管理エリアです。',
	'CoreAdminHome_MenuGeneralSettings' => '全般の設定',
	'CoreAdminHome_Administration' => '管理',
	'CoreAdminHome_EmailServerSettings' => 'メールサーバの設定',
	'CoreAdminHome_OptOutForYourVisitors' => 'ビジターの Piwik オプトアウト',
	'CoreAdminHome_OptOutExplanation' => 'Piwik はインターネット上のプライバシーの提供に専念しています。 ビジターに Piwik ウェブ解析のオプトアウトの選択を提供するために、ウェブサイトの1ページ（プライバシーポリシーのページ等）に次の HTML コードを追加することができます。',
	'CoreAdminHome_OptOutExplanationBis' => 'HTML コードは、ビジターのブラウザにオプトアウト Cookie を設定する、Piwik オプトアウトリンクを含む iFrame を表示します。 iFrame で表示される内容を表示するには、%sここをクリック%sします。',
	'CoreAdminHome_OptOutComplete' => 'オプトアウトが完了しました。 このウェブサイトへのあなたの訪問は、ウェブ解析ツールで記録されません。',
	'CoreAdminHome_OptOutCompleteBis' => 'Cookie をクリアしてオプトアウト Cookie を削除したり、コンピュータやブラウザを変更した場合は、オプトアウト手続きを再度実行する必要があることに注意してください。',
	'CoreAdminHome_YouMayOptOut' => 'このウェブサイトに集められるデータの収集と解析を回避するために、あなたのコンピュータにウェブ解析 Cookie 識別番号を割り当てない選択をすることができます。',
	'CoreAdminHome_YouMayOptOutBis' => 'これを選択するには、オプトアウト Cookie を受信するために、次のチェックボックスにチェックを入れてください。',
	'CoreAdminHome_YouAreOptedIn' => '現在はオプトインです',
	'CoreAdminHome_YouAreOptedOut' => '現在はオプトアウトです',
	'CoreHome_PluginDescription' => 'ウェブ解析リポートのストラクチャーです。',
	'CoreHome_WebAnalyticsReports' => 'ウェブ解析リポート',
	'CoreHome_JavascriptDisabled' => 'Piwik を標準ビューで使用するには JavaScript が有効である必要がありますが、<br />あなたのブラウザでは無効になっているか、サポートされないようです。<br />標準ビューで使用するために、ブラウザのオプションを変更して JavaScript を有効にしてから<br />%1$s再試行してください%2$s。<br />',
	'CoreHome_ThereIsNoDataForThisReport' => 'このリポートのデータがありません。',
	'CoreHome_CategoryNoData' => 'このカテゴリにデータはありません。 "すべての母集団（統計の対象とする集団）を含める" を試してみてください。',
	'CoreHome_ShowJSCode' => '挿入する javascript コードを表示',
	'CoreHome_PageOf_js' => '%1$s / %2$s',
	'CoreHome_PeriodDay' => '日',
	'CoreHome_PeriodWeek' => '週',
	'CoreHome_PeriodMonth' => '月',
	'CoreHome_PeriodYear' => '年',
	'CoreHome_PeriodDays' => '日',
	'CoreHome_PeriodWeeks' => '週',
	'CoreHome_PeriodMonths' => '月',
	'CoreHome_PeriodYears' => '年',
	'CoreHome_DaySu_js' => '日',
	'CoreHome_DayMo_js' => '月',
	'CoreHome_DayTu_js' => '火',
	'CoreHome_DayWe_js' => '水',
	'CoreHome_DayTh_js' => '木',
	'CoreHome_DayFr_js' => '金',
	'CoreHome_DaySa_js' => '土',
	'CoreHome_ShortDay_1_js' => '日',
	'CoreHome_ShortDay_2_js' => '月',
	'CoreHome_ShortDay_3_js' => '火',
	'CoreHome_ShortDay_4_js' => '水',
	'CoreHome_ShortDay_5_js' => '木',
	'CoreHome_ShortDay_6_js' => '金',
	'CoreHome_ShortDay_7_js' => '土',
	'CoreHome_LongDay_1_js' => '日曜日',
	'CoreHome_LongDay_2_js' => '月曜日',
	'CoreHome_LongDay_3_js' => '火曜日',
	'CoreHome_LongDay_4_js' => '水曜日',
	'CoreHome_LongDay_5_js' => '木曜日',
	'CoreHome_LongDay_6_js' => '金曜日',
	'CoreHome_LongDay_7_js' => '土曜日',
	'CoreHome_ShortMonth_1_js' => '1月',
	'CoreHome_ShortMonth_2_js' => '2月',
	'CoreHome_ShortMonth_3_js' => '3月',
	'CoreHome_ShortMonth_4_js' => '4月',
	'CoreHome_ShortMonth_5_js' => '5月',
	'CoreHome_ShortMonth_6_js' => '6月',
	'CoreHome_ShortMonth_7_js' => '7月',
	'CoreHome_ShortMonth_8_js' => '8月',
	'CoreHome_ShortMonth_9_js' => '9月',
	'CoreHome_ShortMonth_10_js' => '10月',
	'CoreHome_ShortMonth_11_js' => '11月',
	'CoreHome_ShortMonth_12_js' => '12月',
	'CoreHome_MonthJanuary_js' => '1月',
	'CoreHome_MonthFebruary_js' => '2月',
	'CoreHome_MonthMarch_js' => '3月',
	'CoreHome_MonthApril_js' => '4月',
	'CoreHome_MonthMay_js' => '5月',
	'CoreHome_MonthJune_js' => '6月',
	'CoreHome_MonthJuly_js' => '7月',
	'CoreHome_MonthAugust_js' => '8月',
	'CoreHome_MonthSeptember_js' => '9月',
	'CoreHome_MonthOctober_js' => '10月',
	'CoreHome_MonthNovember_js' => '11月',
	'CoreHome_MonthDecember_js' => '12月',
	'CorePluginsAdmin_PluginDescription' => 'プラグイン管理のインターフェースです。',
	'CorePluginsAdmin_Plugins' => 'プラグイン',
	'CorePluginsAdmin_PluginsManagement' => 'プラグインの管理',
	'CorePluginsAdmin_MainDescription' => 'プラグインは Piwik の機能性を拡張します。 プラグインをインストールすると、ここで有効化と無効化を行うことができます。',
	'CorePluginsAdmin_Plugin' => 'プラグイン',
	'CorePluginsAdmin_Version' => 'バージョン',
	'CorePluginsAdmin_Status' => '状態',
	'CorePluginsAdmin_Action' => '操作',
	'CorePluginsAdmin_AuthorHomepage' => '作者のホームページ',
	'CorePluginsAdmin_LicenseHomepage' => 'ライセンスのホームページ',
	'CorePluginsAdmin_PluginHomepage' => 'プラグインのホームページ',
	'CorePluginsAdmin_Activated' => '有効',
	'CorePluginsAdmin_Active' => '有効',
	'CorePluginsAdmin_Inactive' => '無効',
	'CorePluginsAdmin_Deactivate' => '無効化',
	'CorePluginsAdmin_Activate' => '有効化',
	'CorePluginsAdmin_MenuPlugins' => 'プラグイン',
	'CoreUpdater_PluginDescription' => 'Piwik アップデートメカニズム',
	'CoreUpdater_UpdateTitle' => 'アップデート',
	'CoreUpdater_DatabaseUpgradeRequired' => 'データベースのアップグレードが必要',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik データベースが旧式のため、継続する前にアップグレードが必要です。',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik データベースが %1$s から新バージョン %2$s にアップグレードされます。',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => '次のプラグインはアップグレードされます： %s',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Piwik のデータベースが大きい場合の重要注意',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Piwik のデータベースが大きい場合、ブラウザでのアップデートの実行には長い時間がかかる場合があります。 このような場合、コマンドラインからアップデートを実行することができます： %s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => 'データベースのタイムアウト、ブラウザのタイムアウト、あるいはその他の問題により Piwik がアップグレードに失敗し、さらにコマンドラインアップデータを使用することができない場合は、Piwik をアップデートするために手作業で SQL クエリーを実行することができます。',
	'CoreUpdater_ClickHereToViewSqlQueries' => '実行する SQL クエリーのリストを表示し、コピーするには、ここをクリックしてください',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => '注意： これらのクエリーを手作業で実行する場合、クエリーのいくつかは失敗することが予想されます。 その場合は単にエラーを無視し、リスト内の次のクエリーを実行してください。',
	'CoreUpdater_ReadyToGo' => '実行してもよろしいですか？',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'アップグレード処理には時間がかかる場合がありますが、しばらくお待ちください。',
	'CoreUpdater_UpgradePiwik' => 'Piwik のアップグレード',
	'CoreUpdater_ErrorDIYHelp' => 'あなたが上級ユーザーであり、データベースアップグレードでエラーに遭遇した場合：',
	'CoreUpdater_ErrorDIYHelp_1' => '問題の原因を特定し、修正してください（memory_limit、max_execution_time など）',
	'CoreUpdater_ErrorDIYHelp_2' => '失敗したアップデートに残っているクエリーを実行してください',
	'CoreUpdater_ErrorDIYHelp_3' => 'Piwik データベースの \'option\' テーブルにある version_core の値を、失敗したアップデートのバージョンに設定して、手作業でテーブルをアップデートしてください',
	'CoreUpdater_ErrorDIYHelp_4' => '残りのアップデートを継続するために、アップデータを再実行してください（ブラウザまたはコマンドラインから）',
	'CoreUpdater_ErrorDIYHelp_5' => 'Piwik を改善することができるように、問題（および解決策）を報告してください',
	'CoreUpdater_HelpMessageContent' => 'アップグレードの間、最も一般的なエラーを説明している %1$s Piwik FAQ %2$sをチェックしてください。%3$s システム管理者にお尋ねください － 彼らはたいていの場合、サーバや MySQL のセットアップに関係するエラーについて、あなたの手助けができるでしょう。',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'アップグレード処理中の致命的なエラー：',
	'CoreUpdater_HelpMessageIntroductionWhenError' => '上記はコアのエラーメッセージです。  原因の説明に役立つはずですが、さらなるヘルプが必要であればこちらをどうぞ：',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'アップグレードは正常に完了しましたが、処理中に問題がありました。 詳細は上記の説明をお読みください。 さらなるヘルプ：',
	'CoreUpdater_UpgradeComplete' => 'アップグレードが完了しました！',
	'CoreUpdater_WarningMessages' => '警告メッセージ：',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'プラグイン更新中のエラー：',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => '次のプラグインを自動的に無効化しました： %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik は正常にアップグレードされました！',
	'CoreUpdater_ContinueToPiwik' => 'Piwik を続ける',
	'CoreUpdater_UpdateAutomatically' => '自動アップデート',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'アップデート可能な Piwik の新バージョンがあります。',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => '自動的にバージョン %s にアップデートするか、パッケージをダウンロードして手作業でインストールすることができます：',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik が現在のインストールに上書きすることができません。 ディレクトリ／ファイルのパーミッションを修正するか、パッケージをダウンロードして手作業でバージョン %s をインストールすることができます：',
	'CoreUpdater_DownloadX' => 'ダウンロード %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik ワンクリックアップデートがキャンセルされました。 あなたが上記のエラーメッセージを修正できない場合は、Piwik を手作業でアップデートすることをお勧めします。%1$s アップデートを始めるには、%2$sアップデートのドキュメント%3$sを参照してください！',
	'CoreUpdater_DownloadingUpdateFromX' => '%s からアップデートをダウンロード中',
	'CoreUpdater_UnpackingTheUpdate' => 'アップデートを展開中',
	'CoreUpdater_VerifyingUnpackedFiles' => '展開したファイルを検証中',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => '%s の設定ファイルのバックアップを作成中',
	'CoreUpdater_InstallingTheLatestVersion' => '最新バージョンをインストール中',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik は正常にアップデートされました！',
	'CoreUpdater_EmptyDatabaseError' => 'データベース %s は空です。 Piwik 設定ファイルを編集または削除する必要があります。',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Piwik バージョン %s は最新です。',
	'CoreUpdater_ExceptionArchiveIncompatible' => '互換性のないアーカイブ： %s',
	'CoreUpdater_ExceptionArchiveEmpty' => '空のアーカイブです。',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'アーカイブが不完全です：いくつかのファイルが不足しています（%s など）。',
	'Dashboard_PluginDescription' => 'ウェブ解析のダッシュボードです。 新しいウィジェットを追加したり、ウィジェットの並び順を変更することで、あなたのダッシュボードをカスタマイズすることができます。 各ユーザーは、ユーザー自身のカスタムダッシュボードにアクセスすることができます。',
	'Dashboard_Dashboard' => 'ダッシュボード',
	'Dashboard_DeleteWidgetConfirm' => '本当にこのウィジェットをダッシュボードから削除しますか？',
	'Dashboard_SelectWidget' => 'ダッシュボードに追加するウィジェットの選択',
	'Dashboard_AddPreviewedWidget_js' => 'プレビューされたウィジェットをダッシュボードに追加します',
	'Dashboard_WidgetPreview_js' => 'ウィジェットのプレビュー',
	'Dashboard_Close_js' => '閉じる',
	'Dashboard_Maximise_js' => '最大化',
	'Dashboard_TitleWidgetInDashboard_js' => 'すでにダッシュボードにあるウィジェットです',
	'Dashboard_TitleClickToAdd_js' => 'クリックするとダッシュボードに追加されます',
	'Dashboard_LoadingWidget_js' => 'ウィジェットを読み込んでいます...',
	'Dashboard_WidgetNotFound_js' => 'ウィジェットが見つかりませんでした',
	'DBStats_PluginDescription' => 'Piwik テーブルによる MySQL データベースの使用量をリポートします。',
	'DBStats_DatabaseUsage' => 'データベースの使用量',
	'DBStats_MainDescription' => 'Piwik はすべてのウェブ解析データを Mysql データベースに保存します。  現在のところ、Piwik テーブルは %s を使用しています。',
	'DBStats_LearnMore' => 'Piwik のデータ処理方法やトラフィックの比較的高いウェブサイトで Piwik をうまく機能させる方法についての詳細は、ドキュメント %s を参照してください。',
	'DBStats_Table' => 'テーブル',
	'DBStats_RowCount' => '行数',
	'DBStats_DataSize' => 'データサイズ',
	'DBStats_IndexSize' => 'インデックスサイズ',
	'DBStats_TotalSize' => '総サイズ',
	'ExampleAPI_PluginDescription' => '例題プラグイン： 特別なコーディングなしで複数のフォーマットにデータをエクスポートする、カスタムプラグインのための API の作成方法です。',
	'ExampleFeedburner_PluginDescription' => '例題プラグイン： Feedburner の購読者をダッシュボードのウィジェットで表示する方法です。',
	'ExampleRssWidget_PluginDescription' => '例題プラグイン： RSS フィードを読むウィジェットの作成方法です。',
	'ExampleUI_PluginDescription' => '例題プラグイン： このプラグインは、Piwik UI との連携方法を示します（テーブル、グラフ等の作成）。',
	'Feedback_PluginDescription' => 'Piwik チームにフィードバックを送信します。 あなたのアイディアや提案を私たちと共有してください！',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => '報告するべきバグや機能要望がありますか？',
	'Feedback_ViewAnswersToFAQ' => '%sFAQ%sの回答を見る',
	'Feedback_WhyAreMyVisitsNoTracked' => '私のウェブサイトへの訪問がトラッキングされないのはなぜ？',
	'Feedback_HowToExclude' => '自分自身の訪問のトラッキングを除外するには？',
	'Feedback_WhyWrongCountry' => '私の訪問が実際の国と異なって示されるのはなぜ？',
	'Feedback_HowToAnonymizeIP' => 'データベースのビジターの IP アドレスをマスクする方法は？',
	'Feedback_VisitTheForums' => '%sフォーラム%sにアクセスする',
	'Feedback_LearnWaysToParticipate' => 'あなたが参加できるすべての方法を%s学んでください%s',
	'Feedback_SpecialRequest' => 'Piwik チームに対して特別なリクエストがありますか？',
	'Feedback_ContactThePiwikTeam' => 'Piwik チームと連絡を取る！',
	'Feedback_IWantTo' => 'あなたの希望：',
	'Feedback_CategoryShareStory' => 'Piwik サクセスストーリーを共有したい',
	'Feedback_CategorySponsor' => 'Piwik のスポンサーになりたい',
	'Feedback_CategoryHire' => 'Piwik コンサルタントを雇いたい',
	'Feedback_CategorySecurity' => 'セキュリティ問題を報告したい',
	'Feedback_MyEmailAddress' => 'メールアドレス：',
	'Feedback_MyMessage' => 'メッセージ',
	'Feedback_DetailsPlease' => '（詳細を含めてください）',
	'Feedback_SendFeedback' => 'フィードバックを送信',
	'Feedback_ManuallySendEmailTo' => 'あなたのメッセージを手作業で次のアドレスへ送ってください：',
	'Feedback_MessageSent' => 'あなたのメッセージは Piwik チームに送信されました。',
	'Feedback_ThankYou' => '私たちが Piwik をより良くするのを支援していただきありがとうございます！',
	'Feedback_ThePiwikTeam' => 'Piwik チーム',
	'Feedback_ExceptionBodyLength' => 'メッセージは少なくとも %s 文字以上が必要です。',
	'Feedback_ExceptionNoUrls' => 'スパムメッセージを防止するため、メッセージに URL を含めることはできません。',
	'Goals_Goals' => '目標',
	'Goals_GoalsOverview' => '目標の概観',
	'Goals_GoalsManagement' => '目標の管理',
	'Goals_PluginDescription' => '目標を作成し、目標コンバージョンに関するリポート（一定期間の推移、ビジット単位の収益、参照元やキーワード単位のコンバージョン等）を表示します。',
	'Goals_ColumnConversions' => 'コンバージョン',
	'Goals_ColumnRevenue' => '収益',
	'Goals_GoalX' => '目標 %s',
	'Goals_GoalConversion' => '目標コンバージョン',
	'Goals_OverallRevenue' => '%s 総収益',
	'Goals_OverallConversionRate' => '%s 総コンバージョン率（目標達成ビジット）',
	'Goals_Conversions' => '%s コンバージョン',
	'Goals_ConversionRate' => '%s コンバージョン率',
	'Goals_NoGoalsNeedAccess' => '管理者またはスーパーユーザーのみが、特定のウェブサイト用の目標を追加することができます。 あなたのウェブサイト用の目標をセットアップするように、Piwik 管理者に依頼してください。<br />トラッキング目標は、あなたのウェブサイトのパフォーマンスを理解し、最大限にするのを支援する、素晴らしい方法です！',
	'Goals_AddNewGoal' => '新しい目標を追加',
	'Goals_AddNewGoalOrEditExistingGoal' => '%s新しい目標の追加%sまたは%s既存の目標の編集%s',
	'Goals_AddGoal_js' => '目標を追加',
	'Goals_UpdateGoal_js' => '目標を更新',
	'Goals_DeleteGoalConfirm_js' => '本当に目標 %s を削除しますか？',
	'Goals_CreateNewGOal' => '新しい目標の作成',
	'Goals_ViewAndEditGoals' => '目標の表示と編集',
	'Goals_GoalName' => '目標名',
	'Goals_GoalIsTriggered' => '目標のトリガー',
	'Goals_GoalIsTriggeredWhen' => '目標のトリガー',
	'Goals_WhenVisitors' => 'ビジター',
	'Goals_WhereThe' => '対象：',
	'Goals_Manually' => '手動',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => 'JavaScript API の trackGoal() を使用した手動トリガー',
	'Goals_VisitUrl' => '特定の URL を訪問（ページまたはページグループ）',
	'Goals_URL' => 'URL',
	'Goals_Filename' => 'ファイル名',
	'Goals_ExternalWebsiteUrl' => '外部ウェブサイトの URL',
	'Goals_Download' => 'ファイルのダウンロード',
	'Goals_ClickOutlink' => '外部ウェブサイトへのリンクをクリック',
	'Goals_Optional' => '（オプション）',
	'Goals_WhereVisitedPageManuallyCallsJavascriptTrackerLearnMore' => '訪問したページに JavaScript の piwikTracker.trackGoal() メソッドのコールが含まれるところ（%s詳細%s）',
	'Goals_DefaultRevenue' => '目標のデフォルト収益',
	'Goals_DefaultRevenueHelp' => '例えば、ビジターによって送信されたコンタクトフォームが、平均して $10 の価値を持つかもしれません。 Piwik は、ビジターセグメントがどれくらいうまく実行しているかを理解するのを助けます。',
	'Goals_ConversionsOverview' => 'コンバージョンの概観',
	'Goals_BestCountries' => 'ベストコンバージョンの国：',
	'Goals_BestKeywords' => 'トップコンバージョンのキーワード：',
	'Goals_BestReferers' => 'ベストコンバージョンの参照元ウェブサイト',
	'Goals_ReturningVisitorsConversionRateIs' => 'リピーターのコンバージョン率は %s です',
	'Goals_NewVisitorsConversionRateIs' => '新規ビジターのコンバージョン率は %s です',
	'Goals_Contains' => '%s を含む',
	'Goals_IsExactly' => '%s と完全に一致する',
	'Goals_MatchesExpression' => '正規表現 %s に一致する',
	'Goals_CaseSensitive' => '大文字小文字を区別する一致',
	'Goals_Pattern' => 'パターン',
	'Goals_ExceptionInvalidMatchingString' => '\'完全に一致する\' を選択した場合、一致文字列は %s で始まる URL である必要があります。 例えば、%s です。',
	'Goals_LearnMoreAboutGoalTrackingDocumentation' => 'ユーザードキュメントで%sPiwik でのトラッキング目標%sについての詳細を確認',
	'Installation_PluginDescription' => 'Piwik のインストール処理を行います。 インストールは通常1回のみですが、設定ファイル（config/config.inc.php）が削除された場合は、インストールが再度開始されます。',
	'Installation_Installation' => 'インストール',
	'Installation_InstallationStatus' => 'インストール状況',
	'Installation_PercentDone' => '%s %% 完了',
	'Installation_NoConfigFound' => 'Piwik の設定ファイルを見つけることができませんでしたが、あなたは Piwik ページにアクセスしようとしています。<br /><b>  »<a href=\'index.php\'>ただちに Piwik をインストール</a>することができます。</b><br /><small>以前に Piwik をインストールしたことがあり、DB に多少のデータがある場合でも心配しないでください。 既存のデータを保持したまま、同じテーブルを再利用することができます！</small>',
	'Installation_DatabaseSetup' => 'データベースのセットアップ',
	'Installation_DatabaseSetupServer' => 'データベースサーバー',
	'Installation_DatabaseSetupLogin' => 'ログイン名',
	'Installation_DatabaseSetupPassword' => 'パスワード',
	'Installation_DatabaseSetupDatabaseName' => 'データベース名',
	'Installation_DatabaseSetupTablePrefix' => 'テーブルプレフィックス',
	'Installation_DatabaseSetupAdapter' => 'アダプタ',
	'Installation_DatabaseErrorConnect' => 'データベースサーバーへの接続中にエラーが発生しました',
	'Installation_DatabaseCheck' => 'データベースの確認',
	'Installation_DatabaseServerVersion' => 'データベースサーバーのバージョン',
	'Installation_DatabaseClientVersion' => 'データベースクライアントのバージョン',
	'Installation_DatabaseCreation' => 'データベースの作成',
	'Installation_PleaseFixTheFollowingErrors' => '次のエラーを修正してください',
	'Installation_LargePiwikInstances' => '高トラフィック環境で Piwik を使用するためのヒント',
	'Installation_JsTag' => 'Javascript タグ',
	'Installation_JsTagArchivingHelp' => '比較的トラフィックの高いウェブサイトでは、Piwik を高速に実行させるために <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">How to setup auto archiving page</a> を参照してください。',
	'Installation_Congratulations' => 'おめでとうございます',
	'Installation_CongratulationsHelp' => '<p>おめでとうございます！ Piwik のインストールは完了しました。</p><p>javascript コードをウェブサイトのページに埋め込み、最初のビジターをお待ちください！</p>',
	'Installation_ContinueToPiwik' => 'Piwik を継続',
	'Installation_SetupWebsite' => 'ウェブサイトのセットアップ',
	'Installation_SetupWebSiteName' => 'ウェブサイトの名前',
	'Installation_SetupWebSiteURL' => 'ウェブサイトの URL',
	'Installation_Timezone' => 'ウェブサイトのタイムゾーン',
	'Installation_SetupWebsiteError' => 'ウェブサイトを追加する際にエラーが発生しました',
	'Installation_SetupWebsiteSetupSuccess' => 'ウェブサイト %s は正常に作成されました！',
	'Installation_SuperUserLogin' => 'スーパーユーザーのログイン',
	'Installation_Password' => 'パスワード',
	'Installation_PasswordRepeat' => 'パスワード（再入力）',
	'Installation_Email' => 'メールアドレス',
	'Installation_SecurityNewsletter' => 'Piwik にメジャーアップグレードやセキュリティ警告がある場合に、自分宛にメールを送信',
	'Installation_CommunityNewsletter' => 'コミュニティアップデート（新しいプラグイン、新機能等）がある場合に、自分宛にメールを送信',
	'Installation_PasswordDoNotMatch' => 'パスワードが一致しませんでした',
	'Installation_Requirements' => 'Piwik の動作環境',
	'Installation_Optional' => 'オプション',
	'Installation_Legend' => '説明',
	'Installation_Extension' => 'エクステンション',
	'Installation_SystemCheck' => 'システムの確認',
	'Installation_SystemCheckPhp' => 'PHP バージョン',
	'Installation_SystemCheckExtensions' => 'その他の必須エクステンション',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik には、mysqli エクステンションか、PDO と pdo_mysql エクステンションの両方の、どちらかが必要です。',
	'Installation_SystemCheckPdoAndMysqliHelp' => 'Linux サーバーでは、次のオプションで PHP をコンパイルします：%1$sphp.ini に次の行を追加します：%2$s',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => '詳細ドキュメント：<a style="color:red" href="http://php.net/pdo">PHP PDO</a>、<a style="color:red" href="http://php.net/mysqli">MYSQLI</a>',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'Windows サーバーでは、php.ini に次の行を追加します：%s',
	'Installation_SystemCheckSplHelp' => 'Standard PHP Library (SPL) を有効にして、PHP の再構築と設定を行う必要があります（通常はデフォルト）。',
	'Installation_SystemCheckZlibHelp' => '"zlib" のサポートを有効にして、PHP の再構築と設定を行う必要があります（--with-zlib）。',
	'Installation_SystemCheckIconvHelp' => '"iconv" のサポートを有効にして、PHP の再構築と設定を行う必要があります（--with-iconv）。',
	'Installation_SystemCheckOtherExtensions' => 'その他のエクステンション',
	'Installation_SystemCheckWarnLibXmlHelp' => '他のコア PHP エクステンションで必要となるため、"libxml" エクステンションを有効にする必要があります（例えば "php-libxml" パッケージをインストールする）。',
	'Installation_SystemCheckWarnJsonHelp' => 'より良いパフォーマンスのために、"json" エクステンションを有効にする必要があります（例えば "php-json" パッケージをインストールする）。',
	'Installation_SystemCheckWarnDomHelp' => '"dom" エクステンションを有効にする必要があります（例えば "php-dom" と "php-xml" パッケージのどちらか、あるいは両方をインストールする）。',
	'Installation_SystemCheckWarnSimpleXMLHelp' => '"SimpleXML" エクステンションを有効にする必要があります（例えば "php-simplexml" と "php-xml" パッケージのどちらか、あるいは両方をインストールする）。',
	'Installation_SystemCheckWriteDirs' => '書き込み権限のあるディレクトリ',
	'Installation_SystemCheckWriteDirsHelp' => 'この Linux システムでこの問題を修正するには、次のコマンドを打ち込んでみてください',
	'Installation_SystemCheckMemoryLimit' => 'メモリー制限',
	'Installation_SystemCheckMemoryLimitHelp' => 'アクセス数の多いウェブサイトでは、アーカイブ処理の実行に、現在許可されている以上に多くのメモリを必要とする場合があります。<br />必要であれば、php.ini ファイルのディレクティブ memory_limit を参照してください。',
	'Installation_SystemCheckOpenURL' => 'オープン URL',
	'Installation_SystemCheckOpenURLHelp' => 'ニュースレターの定期購読、アップデートの通知、ワンクリックアップデートには、"curl" エクステンション、allow_url_fopen=On、または fsockopen() が有効である必要があります。',
	'Installation_SystemCheckGD' => 'GD > 2.x （グラフィック）',
	'Installation_SystemCheckGDHelp' => 'スパークライン（小さなグラフ）は動作しません。',
	'Installation_SystemCheckFunctions' => '必須関数',
	'Installation_SystemCheckOtherFunctions' => 'その他の関数',
	'Installation_SystemCheckTimeLimitHelp' => 'アクセス数の多いウェブサイトでは、アーカイブ処理の実行に、現在許可されている以上に多くの時間を必要とする場合があります。<br />必要であれば、php.ini ファイルのディレクティブ max_execution_time を参照してください。',
	'Installation_SystemCheckMailHelp' => 'mail() 関数がない場合、フィードバックとパスワード紛失のメッセージを送信することができません。',
	'Installation_SystemCheckParseIniFileHelp' => 'この組み込み関数はホストで無効化されています。 Piwik はこの関数のエミュレートを試みますが、さらなるセキュリティ制限に遭遇する場合があります。 また、トラッカーのパフォーマンスにも影響を与えます。',
	'Installation_SystemCheckGlobHelp' => 'この組み込み関数はホストで無効化されています。 Piwik はこの関数のエミュレートを試みますが、さらなるセキュリティ制限に遭遇する場合があります。 また、機能性にも影響を与える場合があります。',
	'Installation_SystemCheckDebugBacktraceHelp' => 'View::factory はコール側モジュールのビューを作成することができません。',
	'Installation_SystemCheckCreateFunctionHelp' => 'Piwik はコールバックに匿名関数を使用します。',
	'Installation_SystemCheckEvalHelp' => 'HTML QuickForm と Smarty テンプレートシステムで必須です。',
	'Installation_SystemCheckGzcompressHelp' => 'zlib エクステンションと gzcompress() 関数を有効にする必要があります。',
	'Installation_SystemCheckGzuncompressHelp' => 'zlib エクステンションと gzuncompress() 関数を有効にする必要があります。',
	'Installation_SystemCheckMbstring' => 'mbstring',
	'Installation_SystemCheckMbstringExtensionHelp' => 'mbstring エクステンションは、コンマ区切りの値(CSV)やタブ区切りの値(TSV)を使用する API レスポンスのマルチバイト文字用に必要となります。',
	'Installation_SystemCheckMbstringFuncOverloadHelp' => 'mbstring.func_overload を "0" に設定する必要があります。',
	'Installation_SystemCheckFileIntegrity' => 'ファイルの整合性',
	'Installation_SystemCheckAutoUpdateHelp' => '注意： Piwik のワンクリックアップデートには、Piwik のフォルダとその内容に書き込み権限が必要となります。',
	'Installation_SystemCheckError' => 'エラー発生 - 次の処理へ進む前に修正する必要があります。',
	'Installation_SystemCheckWarning' => 'Piwik は正常に動作しますが、いくつかの機能は動作しないかもしれません。',
	'Installation_SystemCheckTracker' => 'トラッカー状況',
	'Installation_SystemCheckTrackerHelp' => 'piwik.php に対する GET リクエストが失敗しました。 この URL を mod_security と HTTP 認証からホワイトリスト化してください。',
	'Installation_Tables' => 'テーブルの作成',
	'Installation_TablesWithSameNamesFound' => '%1$s既存のデータベース内のいくつかのテーブル%2$sが、Piwik が作成しようとしているテーブルと同じ名前を持っています',
	'Installation_TablesFound' => '次のテーブルがデータベース内で見つかりました',
	'Installation_TablesWarningHelp' => '既存のデータベーステーブルを再利用するか、データベース内の全データを消去してクリーンインストールするかを選択してください。',
	'Installation_TablesReuse' => '既存テーブルを再利用',
	'Installation_TablesDelete' => '検出されたテーブルを削除',
	'Installation_TablesDeletedSuccess' => '既存の Piwik テーブルは正常に削除されました',
	'Installation_TablesCreatedSuccess' => 'テーブルは正常に作成されました！',
	'Installation_DatabaseCreatedSuccess' => 'データベース %s は正常に作成されました！',
	'Installation_GoBackAndDefinePrefix' => '戻って、Piwik テーブルのプレフィックスを定義する',
	'Installation_ConfirmDeleteExistingTables' => '本当にデータベースからテーブル %s を削除しますか？ 警告： これらのテーブルのデータを復旧することはできません！',
	'Installation_Welcome' => 'ようこそ！',
	'Installation_WelcomeHelp' => '<p>Piwik は、ビジターからあなたが必要とする情報を収集することを容易にする、オープンソースのウェブ解析ソフトウェアです。</p><p>この処理は %s の簡単なステップに分かれていて、5分程度で完了します。</p>',
	'Installation_ConfigurationHelp' => 'Piwik 設定ファイルが誤設定されているようです。 config/config.ini.php を削除してインストールを再開するか、データベースの接続設定を修正してください。',
	'Installation_ErrorInvalidState' => 'エラー： インストール処理のステップを省略しようとしたか、Cookie が無効か、Piwik 設定ファイルがすでに作成されています。%1$sCookie が有効になっていることを確認してから%2$s、%3$sインストールの最初のページ%4$sに戻ってください。',
	'LanguagesManager_PluginDescription' => 'Piwik インターフェイスで利用可能な言語リストを表示します。 選択された言語は、各ユーザーの優先設定に保存されます。',
	'LanguagesManager_AboutPiwikTranslations' => 'Piwik の翻訳について',
	'Live_PluginDescription' => 'ビジターをリアルタイムにライブでスパイします！',
	'Live_LinkVisitorLog' => '詳細なビジターログを表示',
	'Live_Actions' => 'アクション',
	'Live_Action' => 'アクション',
	'Live_VisitorsInRealTime' => 'リアルタイムのビジター',
	'Live_VisitorLog' => 'ビジターログ',
	'Live_Time' => '時間',
	'Live_Referrer_URL' => '参照元 URL',
	'Live_LastMinutes' => '最近の %s 分',
	'Live_LastHours' => '最近の %s 時間',
	'Live_GoalType' => 'タイプ',
	'Live_GoalTime' => '最初のコンバージョン時間',
	'Live_GoalRevenue' => '収益',
	'Live_GoalDetails' => '詳細',
	'Login_PluginDescription' => 'ログイン認証プラグインは信用証明物を、スーパーユーザー用はconfig/config.inc.php から、その他のユーザー用はデータベースから読み込みます。 別の認証メカニズム（OpenID、htaccess、カスタム認証等）を導入したい場合は、簡単に置き換えることができます。',
	'Login_LoginPasswordNotCorrect' => 'ユーザー名またはパスワードが正しくありません',
	'Login_Password' => 'パスワード',
	'Login_PasswordRepeat' => 'パスワード（再入力）',
	'Login_ChangePassword' => 'パスワードの変更',
	'Login_LoginOrEmail' => 'ユーザー名またはメールアドレス',
	'Login_RememberMe' => '次回の入力を省略',
	'Login_LogIn' => 'ログイン',
	'Login_Logout' => 'ログアウト',
	'Login_LostYourPassword' => 'パスワードをお忘れですか？',
	'Login_RemindPassword' => 'パスワードの再発行',
	'Login_PasswordResetToken' => 'パスワード再発行のトークン',
	'Login_PasswordReminder' => 'ユーザー名またはメールアドレスを入力してください。 パスワードをリセットするための案内をメールで送信します。',
	'Login_PasswordsDoNotMatch' => 'パスワードが一致しません。',
	'Login_PasswordSuccessfullyChanged' => 'パスワードは正常に変更されました！',
	'Login_InvalidUsernameEmail' => 'ユーザー名またはメールアドレスが無効です',
	'Login_InvalidOrExpiredToken' => 'トークンが無効または期限切れです。',
	'Login_MailTopicPasswordRecovery' => 'パスワードの再発行',
	'Login_MailPasswordRecoveryBody' => '%1$s さん、%2$s さんからパスワードリセットのリクエストを受け取りました。\n\nあなたのパスワードをリセットするには、以下の説明に従ってください。\n\n\n\n1) 以下のパスワードリセットフォームへ行きます\n\n   %3$s\n\n\n\n2) 以下のトークンを入力します\n\n   %4$s\n\n\n\n3) フォームに記入（新しいパスワードを2回）し、送信します\n\n\n\n注意：このトークンは24時間で期限が切れます。',
	'Login_PasswordSent' => 'パスワードをリセットするための案内を送信しました。 メールを確認してください。',
	'Login_ContactAdmin' => '考えられる理由： ホストで mail() 関数が無効にされている可能性があります。<br />Piwik 管理者にご連絡ください。',
	'Login_ExceptionPasswordMD5HashExpected' => 'パスワードパラメータは、パスワードの MD5 ハッシュ値であることを想定されています。',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'スーパーユーザーは、\'%s\'メカニズムを使用した認証はできません。',
	'Mobile_AnonymousAccess' => '匿名アクセス',
	'Mobile_AccessUrlLabel' => 'Piwik アクセス URL',
	'Mobile_EnableGraphsLabel' => 'グラフの表示',
	'Mobile_DefaultReportDate' => 'リポートの日付',
	'Mobile_MultiChartLabel' => 'スパークラインの表示',
	'Mobile_NetworkNotReachable' => 'ネットワークに到達できませんでした',
	'Mobile_SaveSuccessError' => '設定を確認してください',
	'Mobile_YouAreOffline' => '現在はオフラインです',
	'MultiSites_PluginDescription' => 'マルチサイト運営の概要や統計を表示します。 現在は、コア Piwik プラグインとしてメンテナンスされています。',
	'MultiSites_Evolution' => '推移',
	'Provider_PluginDescription' => 'ビジターのプロバイダをリポートします。',
	'Provider_WidgetProviders' => 'プロバイダ',
	'Provider_ColumnProvider' => 'プロバイダ',
	'Provider_SubmenuLocationsProvider' => '所在地とプロバイダ',
	'Referers_PluginDescription' => '検索エンジン、キーワード、ウェブサイト、キャンペーントラッキング、直接アクセスの参照元データをリポートします。',
	'Referers_Referers' => '参照元',
	'Referers_SearchEngines' => '検索エンジン',
	'Referers_Keywords' => 'キーワード',
	'Referers_DirectEntry' => '直接アクセス',
	'Referers_Websites' => 'ウェブサイト',
	'Referers_Campaigns' => 'キャンペーン',
	'Referers_Evolution' => '一定期間の推移',
	'Referers_Type' => '参照元タイプ',
	'Referers_ColumnRefererType' => '参照元タイプ',
	'Referers_ColumnSearchEngine' => '検索エンジン',
	'Referers_ColumnWebsite' => 'ウェブサイト',
	'Referers_ColumnWebsitePage' => 'ウェブサイトページ',
	'Referers_ColumnKeyword' => 'キーワード',
	'Referers_ColumnCampaign' => 'キャンペーン',
	'Referers_DetailsByRefererType' => '参照元タイプごとの詳細',
	'Referers_TypeDirectEntries' => '%s 直接アクセス',
	'Referers_TypeSearchEngines' => '%s 検索エンジン経由',
	'Referers_TypeWebsites' => '%s ウェブサイト経由',
	'Referers_TypeCampaigns' => '%s キャンペーン経由',
	'Referers_Distinct' => '参照元タイプごとの個別参照元',
	'Referers_DistinctSearchEngines' => '個別の検索エンジン',
	'Referers_DistinctKeywords' => '個別のキーワード',
	'Referers_DistinctCampaigns' => '個別のキャンペーン',
	'Referers_DistinctWebsites' => '個別のウェブサイト',
	'Referers_UsingNDistinctUrls' => '（%s の個別 URL を使用）',
	'Referers_SubmenuOverview' => '概観',
	'Referers_SubmenuSearchEngines' => '検索エンジンとキーワード',
	'Referers_SubmenuWebsites' => 'ウェブサイト',
	'Referers_SubmenuCampaigns' => 'キャンペーン',
	'Referers_WidgetKeywords' => 'キーワード一覧',
	'Referers_WidgetCampaigns' => 'キャンペーン一覧',
	'Referers_WidgetExternalWebsites' => '外部ウェブサイト一覧',
	'Referers_WidgetSearchEngines' => 'ベスト検索エンジン',
	'Referers_WidgetOverview' => '概観',
	'SecurityInfo_PluginDescription' => 'PHP セキュリティコンソーシアムの PhpSecInfo に基づき、PHP 環境に関するセキュリティ情報と、改善のための提案を提供します。 これは、多層のセキュリティアプローチにおけるツールであり、安全な開発プラクティスに取って代わるものでも、コード／アプリケーション監査でもありません。',
	'SecurityInfo_Security' => 'セキュリティ',
	'SecurityInfo_SecurityInformation' => 'PHP セキュリティ情報',
	'SecurityInfo_Test' => 'テスト',
	'SecurityInfo_Result' => '結果',
	'SEO_SeoRankings' => 'SEO ランキング',
	'SEO_AlexaRank' => 'Alexa ランク',
	'SEO_DomainAge' => 'ドメインエイジ',
	'SEO_Rank' => 'ランク',
	'SEO_Backlinks' => 'バックリンク',
	'SEO_Pages' => 'ページ',
	'SEO_SEORankingsFor' => '%s の SEO ランキング',
	'SitesManager_PluginDescription' => 'Piwik でのウェブサイト管理は、新規ウェブサイトの追加、既存ウェブサイトの編集、ページに挿入する JavaScript コードの表示を行うことができます。 また、すべての動作は API を通じて利用することができます。',
	'SitesManager_Sites' => 'ウェブサイト',
	'SitesManager_TrackingTags' => '%s 用トラッキングタグ',
	'SitesManager_WebsitesManagement' => 'ウェブサイトの管理',
	'SitesManager_MainDescription' => 'ウェブ解析リポートにはウェブサイトが必要です！ ウェブサイトの追加、更新、削除と、ページに挿入する Javascript を表示します。',
	'SitesManager_JsTrackingTag' => 'JavaScript トラッキングタグ',
	'SitesManager_JsTrackingTagHelp' => '以下は、すべてのページに埋め込むべき JavaScript トラッキングタグです',
	'SitesManager_ShowTrackingTag' => 'トラッキングタグを表示',
	'SitesManager_NoWebsites' => '管理できるウェブサイトがありません。',
	'SitesManager_AddSite' => '新しいサイトの追加',
	'SitesManager_NotFound' => 'ウェブサイトが見つかりませんでした：',
	'SitesManager_AliasUrlHelp' => 'これは推奨されますが、必須ではありません。 ビジターがこのウェブサイトのアクセスに使用するさまざまな URL を指定するには、1行に1つの URL を入力します。 ウェブサイトの URL エイリアスは、[参照元]>[ウェブサイト]のリポートには表示されません。 URL の \'www\' の有無は、Piwik が両方とも考慮するため、指定する必要がないことに注意してください。',
	'SitesManager_Urls' => 'URL',
	'SitesManager_MenuSites' => 'ウェブサイト',
	'SitesManager_DeleteConfirm_js' => '本当にウェブサイト %s を削除しますか？',
	'SitesManager_ExceptionDeleteSite' => '登録された唯一のウェブサイトであるため、このウェブサイトを削除することはできません。 はじめに新しいウェブサイトを追加し、その後でこれを削除してください。',
	'SitesManager_ExceptionNoUrl' => 'サイト用のURLを最低でも1つ指定する必要があります。',
	'SitesManager_ExceptionEmptyName' => 'サイト名を空欄にはできません。',
	'SitesManager_ExceptionInvalidUrl' => 'URL \'%s\' は有効なURLではありません。',
	'SitesManager_ExceptionInvalidTimezone' => 'タイムゾーン "%s" は有効ではありません。 有効なタイムゾーンを入力してください。',
	'SitesManager_ExceptionInvalidCurrency' => '通貨 "%s" は有効ではありません。 有効な通貨文字（例：%s）を入力してください。',
	'SitesManager_ExceptionInvalidIPFormat' => '除外する IP "%s" は有効な IP 形式（例：%s）ではありません。',
	'SitesManager_SuperUserCan' => 'スーパーユーザーは、新しいウェブサイト用の%s全般設定を指定%sすることができます。',
	'SitesManager_ExcludedIps' => '除外 IP',
	'SitesManager_GlobalListExcludedIps' => '全般的な除外 IP リスト',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => '次の IP は、全ウェブサイトのトラッキングから除外されます。',
	'SitesManager_ExcludedParameters' => '除外パラメータ',
	'SitesManager_GlobalListExcludedQueryParameters' => '全般的な除外クエリー URL パラメータ',
	'SitesManager_ListOfQueryParametersToBeExcludedOnAllWebsites' => '次のクエリー URL パラメータは、全ウェブサイトの URL から除外されます。',
	'SitesManager_ListOfQueryParametersToExclude' => 'ページ URL のリポートから除外する URL クエリーパラメータのリストを、1行に1つずつ入力します。',
	'SitesManager_PiwikWillAutomaticallyExcludeCommonSessionParameters' => '一般的なセッションパラメータ(%s)は、Piwik が自動的に除外します。',
	'SitesManager_HelpExcludedIps' => 'Piwik のトラッキングから除外したい IP のリストを、1行に1つずつ入力します。 IP にはワイルドカード（例：%1$s や %2$s）を使用することができます。',
	'SitesManager_YourCurrentIpAddressIs' => 'あなたの現在の IP アドレスは %s です。',
	'SitesManager_SelectACity' => '都市を選択',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'あなたと同じタイムゾーンの都市を選択します。',
	'SitesManager_ChangingYourTimezoneWillOnlyAffectDataForward' => 'タイムゾーンの変更は、今後のデータにのみ反映され、過去のデータには適用されません。',
	'SitesManager_AdvancedTimezoneSupportNotFound' => 'このサーバーの PHP では拡張タイムゾーンがサポートされていません（PHP>=5.2 でサポート）。 手作業で UTC オフセットを指定します。',
	'SitesManager_UTCTimeIs' => 'UTC 時間は %s です。',
	'SitesManager_Timezone' => 'タイムゾーン',
	'SitesManager_GlobalWebsitesSettings' => '全般的なウェブサイト設定',
	'SitesManager_DefaultTimezoneForNewWebsites' => '新しいウェブサイトのデフォルトタイムゾーン',
	'SitesManager_SelectDefaultTimezone' => '新しいウェブサイトのデフォルトとして選択される、タイムゾーンを選択します。',
	'SitesManager_Currency' => '通貨',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => '通貨文字は目標収益の隣に表示されます。',
	'SitesManager_DefaultCurrencyForNewWebsites' => '新しいウェブサイトのデフォルト通貨',
	'SitesManager_SelectDefaultCurrency' => '新しいウェブサイトのデフォルトとして設定される、通貨を選択します。',
	'TranslationsAdmin_PluginDescription' => 'Piwik をあなたの母国語に翻訳するのを支援します。',
	'TranslationsAdmin_MenuTranslations' => '翻訳',
	'TranslationsAdmin_MenuLanguages' => '言語',
	'TranslationsAdmin_LanguageCode' => '言語コード',
	'TranslationsAdmin_Plugin' => 'プラグイン',
	'TranslationsAdmin_Definition' => '定義',
	'TranslationsAdmin_DefaultString' => 'デフォルト文字列 （英語）',
	'TranslationsAdmin_TranslationString' => '翻訳文字列 （現在の言語： %s）',
	'TranslationsAdmin_Translations' => '翻訳',
	'TranslationsAdmin_FixPermissions' => 'ファイルシステムのパーミッションを修正してください',
	'TranslationsAdmin_AddLanguage' => '言語の追加',
	'TranslationsAdmin_Export' => '言語のエクスポート',
	'TranslationsAdmin_Import' => '言語のインポート',
	'TranslationsAdmin_ShowOnlyEmpty' => '不足翻訳のみを表示',
	'UserCountry_PluginDescription' => 'ビジターの国をリポートします。',
	'UserCountry_Country' => '国',
	'UserCountry_Continent' => '大陸',
	'UserCountry_DistinctCountries' => '%s 個別の国々',
	'UserCountry_Location' => '位置',
	'UserCountry_SubmenuLocations' => '位置',
	'UserCountry_WidgetContinents' => 'ビジターの大陸',
	'UserCountry_WidgetCountries' => 'ビジターの国々',
	'UserCountry_country_ac' => 'アセンション島',
	'UserCountry_country_ad' => 'アンドラ',
	'UserCountry_country_ae' => 'アラブ首長国連邦',
	'UserCountry_country_af' => 'アフガニスタン',
	'UserCountry_country_ag' => 'アンティグア・バーブーダ',
	'UserCountry_country_ai' => 'アンギラ',
	'UserCountry_country_al' => 'アルバニア',
	'UserCountry_country_am' => 'アルメニア',
	'UserCountry_country_an' => 'オランダ領アンティル',
	'UserCountry_country_ao' => 'アンゴラ',
	'UserCountry_country_aq' => '南極大陸',
	'UserCountry_country_ar' => 'アルゼンチン',
	'UserCountry_country_as' => 'アメリカ領サモア',
	'UserCountry_country_at' => 'オーストリア',
	'UserCountry_country_au' => 'オーストラリア',
	'UserCountry_country_aw' => 'アルバ（オランダ）',
	'UserCountry_country_ax' => 'オーランド諸島',
	'UserCountry_country_az' => 'アゼルバイジャン',
	'UserCountry_country_ba' => 'ボスニア・ヘルツェゴビナ',
	'UserCountry_country_bb' => 'バルバドス',
	'UserCountry_country_bd' => 'バングラデシュ',
	'UserCountry_country_be' => 'ベルギー',
	'UserCountry_country_bf' => 'ブルキナファソ',
	'UserCountry_country_bg' => 'ブルガリア',
	'UserCountry_country_bh' => 'バーレーン',
	'UserCountry_country_bi' => 'ブルンジ',
	'UserCountry_country_bj' => 'ベナン',
	'UserCountry_country_bl' => 'サン・バルテルミー島',
	'UserCountry_country_bm' => 'バミューダ諸島（英）',
	'UserCountry_country_bn' => 'ブルネイ',
	'UserCountry_country_bo' => 'ボリビア',
	'UserCountry_country_br' => 'ブラジル',
	'UserCountry_country_bs' => 'バハマ',
	'UserCountry_country_bt' => 'ブータン',
	'UserCountry_country_bu' => 'ビルマ',
	'UserCountry_country_bv' => 'ブーベ島（ノルウェー）',
	'UserCountry_country_bw' => 'ボツワナ',
	'UserCountry_country_by' => 'ベラルーシ',
	'UserCountry_country_bz' => 'ベリーズ',
	'UserCountry_country_ca' => 'カナダ',
	'UserCountry_country_cc' => 'ココス諸島（オーストラリア）',
	'UserCountry_country_cd' => 'コンゴ民主共和国',
	'UserCountry_country_cf' => '中央アフリカ共和国',
	'UserCountry_country_cg' => 'コンゴ共和国',
	'UserCountry_country_ch' => 'スイス',
	'UserCountry_country_ci' => 'コートジボワール',
	'UserCountry_country_ck' => 'クック諸島（ニュージーランド）',
	'UserCountry_country_cl' => 'チリ',
	'UserCountry_country_cm' => 'カメルーン',
	'UserCountry_country_cn' => '中国',
	'UserCountry_country_co' => 'コロンビア',
	'UserCountry_country_cp' => 'クリッパートン島',
	'UserCountry_country_cr' => 'コスタリカ',
	'UserCountry_country_cs' => 'セルビア・モンテネグロ',
	'UserCountry_country_cu' => 'キューバ',
	'UserCountry_country_cv' => 'カーボベルデ',
	'UserCountry_country_cx' => 'クリスマス島（オーストラリア）',
	'UserCountry_country_cy' => 'キプロス',
	'UserCountry_country_cz' => 'チェコ',
	'UserCountry_country_de' => 'ドイツ',
	'UserCountry_country_dg' => 'ディエゴガルシア島',
	'UserCountry_country_dj' => 'ジブチ',
	'UserCountry_country_dk' => 'デンマーク',
	'UserCountry_country_dm' => 'ドミニカ',
	'UserCountry_country_do' => 'ドミニカ共和国',
	'UserCountry_country_dz' => 'アルジェリア',
	'UserCountry_country_ea' => 'セウタ、メリリャ',
	'UserCountry_country_ec' => 'エクアドル',
	'UserCountry_country_ee' => 'エストニア',
	'UserCountry_country_eg' => 'エジプト',
	'UserCountry_country_eh' => '西サハラ',
	'UserCountry_country_er' => 'エリトリア',
	'UserCountry_country_es' => 'スペイン',
	'UserCountry_country_et' => 'エチオピア',
	'UserCountry_country_eu' => '欧州連合',
	'UserCountry_country_fi' => 'フィンランド',
	'UserCountry_country_fj' => 'フィジー',
	'UserCountry_country_fk' => 'フォークランド諸島（英）',
	'UserCountry_country_fm' => 'ミクロネシア連邦',
	'UserCountry_country_fo' => 'フェロー諸島（デンマーク）',
	'UserCountry_country_fr' => 'フランス',
	'UserCountry_country_fx' => 'フランス(本国)',
	'UserCountry_country_ga' => 'ガボン',
	'UserCountry_country_gb' => 'グレートブリテン島（英）',
	'UserCountry_country_gd' => 'グレナダ',
	'UserCountry_country_ge' => 'グルジア',
	'UserCountry_country_gf' => 'フランス領ギアナ',
	'UserCountry_country_gg' => 'ガーンジー島（英）',
	'UserCountry_country_gh' => 'ガーナ',
	'UserCountry_country_gi' => 'ジブラルタル（英）',
	'UserCountry_country_gl' => 'グリーンランド（デンマーク）',
	'UserCountry_country_gm' => 'ガンビア',
	'UserCountry_country_gn' => 'ギニア',
	'UserCountry_country_gp' => 'グアドループ（仏）',
	'UserCountry_country_gq' => '赤道ギニア',
	'UserCountry_country_gr' => 'ギリシャ',
	'UserCountry_country_gs' => 'サウスジョージア・サウスサンドウィッチ諸島（英）',
	'UserCountry_country_gt' => 'グアテマラ',
	'UserCountry_country_gu' => 'グアム（米）',
	'UserCountry_country_gw' => 'ギニアビサウ',
	'UserCountry_country_gy' => 'ガイアナ',
	'UserCountry_country_hk' => '香港（中）',
	'UserCountry_country_hm' => 'ハード島マクドナルド諸島（オーストラリア）',
	'UserCountry_country_hn' => 'ホンジュラス',
	'UserCountry_country_hr' => 'クロアチア',
	'UserCountry_country_ht' => 'ハイチ',
	'UserCountry_country_hu' => 'ハンガリー',
	'UserCountry_country_ic' => 'カナリア諸島',
	'UserCountry_country_id' => 'インドネシア',
	'UserCountry_country_ie' => 'アイルランド',
	'UserCountry_country_il' => 'イスラエル',
	'UserCountry_country_im' => 'マン島（英）',
	'UserCountry_country_in' => 'インド',
	'UserCountry_country_io' => 'インド洋地域（英）',
	'UserCountry_country_iq' => 'イラク',
	'UserCountry_country_ir' => 'イラン',
	'UserCountry_country_is' => 'アイスランド',
	'UserCountry_country_it' => 'イタリア',
	'UserCountry_country_je' => 'ジャージー（英）',
	'UserCountry_country_jm' => 'ジャマイカ',
	'UserCountry_country_jo' => 'ヨルダン',
	'UserCountry_country_jp' => '日本',
	'UserCountry_country_ke' => 'ケニア',
	'UserCountry_country_kg' => 'キルギス',
	'UserCountry_country_kh' => 'カンボジア',
	'UserCountry_country_ki' => 'キリバス',
	'UserCountry_country_km' => 'コモロ',
	'UserCountry_country_kn' => 'セントクリストファー・ネイビス',
	'UserCountry_country_kp' => '北朝鮮',
	'UserCountry_country_kr' => '韓国',
	'UserCountry_country_kw' => 'クウェート',
	'UserCountry_country_ky' => 'ケイマン諸島（英',
	'UserCountry_country_kz' => 'カザフスタン',
	'UserCountry_country_la' => 'ラオス',
	'UserCountry_country_lb' => 'レバノン',
	'UserCountry_country_lc' => 'セントルシア',
	'UserCountry_country_li' => 'リヒテンシュタイン',
	'UserCountry_country_lk' => 'スリランカ',
	'UserCountry_country_lr' => 'リベリア',
	'UserCountry_country_ls' => 'レソト',
	'UserCountry_country_lt' => 'リトアニア',
	'UserCountry_country_lu' => 'ルクセンブルグ',
	'UserCountry_country_lv' => 'ラトビア',
	'UserCountry_country_ly' => 'リビア',
	'UserCountry_country_ma' => 'モロッコ',
	'UserCountry_country_mc' => 'モナコ',
	'UserCountry_country_md' => 'モルドバ',
	'UserCountry_country_me' => 'モンテネグロ',
	'UserCountry_country_mf' => 'サン・マルタン島',
	'UserCountry_country_mg' => 'マダガスカル',
	'UserCountry_country_mh' => 'マーシャル諸島',
	'UserCountry_country_mk' => 'マケドニア',
	'UserCountry_country_ml' => 'マリ',
	'UserCountry_country_mm' => 'ミャンマー',
	'UserCountry_country_mn' => 'モンゴル',
	'UserCountry_country_mo' => 'マカオ（中）',
	'UserCountry_country_mp' => '北マリアナ諸島（米）',
	'UserCountry_country_mq' => 'マルティニーク（仏）',
	'UserCountry_country_mr' => 'モーリタニア',
	'UserCountry_country_ms' => 'モントセラト（英）',
	'UserCountry_country_mt' => 'マルタ',
	'UserCountry_country_mu' => 'モーリシャス',
	'UserCountry_country_mv' => 'モルディブ',
	'UserCountry_country_mw' => 'マラウイ',
	'UserCountry_country_mx' => 'メキシコ',
	'UserCountry_country_my' => 'マレーシア',
	'UserCountry_country_mz' => 'モザンビーク',
	'UserCountry_country_na' => 'ナミビア',
	'UserCountry_country_nc' => 'ニューカレドニア（仏）',
	'UserCountry_country_ne' => 'ニジェール',
	'UserCountry_country_nf' => 'ノーフォーク島（オーストラリア）',
	'UserCountry_country_ng' => 'ナイジェリア',
	'UserCountry_country_ni' => 'ニカラグア',
	'UserCountry_country_nl' => 'オランダ',
	'UserCountry_country_no' => 'ノルウェー',
	'UserCountry_country_np' => 'ネパール',
	'UserCountry_country_nr' => 'ナウル',
	'UserCountry_country_nt' => '中立地帯',
	'UserCountry_country_nu' => 'ニウエ（ニュージーランド）',
	'UserCountry_country_nz' => 'ニュージーランド',
	'UserCountry_country_om' => 'オマーン',
	'UserCountry_country_pa' => 'パナマ',
	'UserCountry_country_pe' => 'ペルー',
	'UserCountry_country_pf' => 'ポリネシア（フランス領）',
	'UserCountry_country_pg' => 'パプアニューギニア',
	'UserCountry_country_ph' => 'フィリピン',
	'UserCountry_country_pk' => 'パキスタン',
	'UserCountry_country_pl' => 'ポーランド',
	'UserCountry_country_pm' => 'サンピエール島・ミクロン島（カナダ領）',
	'UserCountry_country_pn' => 'ピトケアン諸島',
	'UserCountry_country_pr' => 'プエルトリコ（アメリカ領）',
	'UserCountry_country_ps' => 'パレスチナ自治区',
	'UserCountry_country_pt' => 'ポルトガル',
	'UserCountry_country_pw' => 'パラオ',
	'UserCountry_country_py' => 'パラグアイ',
	'UserCountry_country_qa' => 'カタール',
	'UserCountry_country_re' => 'レユニオン（フランス領）',
	'UserCountry_country_ro' => 'ルーマニア',
	'UserCountry_country_rs' => 'セルビア',
	'UserCountry_country_ru' => 'ロシア連邦',
	'UserCountry_country_rw' => 'ルワンダ',
	'UserCountry_country_sa' => 'サウジアラビア',
	'UserCountry_country_sb' => 'ソロモン諸島',
	'UserCountry_country_sc' => 'セーシェル',
	'UserCountry_country_sd' => 'スーダン',
	'UserCountry_country_se' => 'スウェーデン',
	'UserCountry_country_sf' => 'フィンランド',
	'UserCountry_country_sg' => 'シンガポール',
	'UserCountry_country_sh' => 'セントヘレナ（イギリス領）',
	'UserCountry_country_si' => 'スロベニア',
	'UserCountry_country_sj' => 'スヴァールバル諸島、ヤンマイエン島（ノルウェー領）',
	'UserCountry_country_sk' => 'スロバキア',
	'UserCountry_country_sl' => 'シエラレオネ',
	'UserCountry_country_sm' => 'サンマリノ',
	'UserCountry_country_sn' => 'セネガル',
	'UserCountry_country_so' => 'ソマリア',
	'UserCountry_country_sr' => 'スリナム',
	'UserCountry_country_st' => 'サントメ・プリンシペ',
	'UserCountry_country_su' => '旧ソビエト連邦',
	'UserCountry_country_sv' => 'エルサルバドル',
	'UserCountry_country_sy' => 'シリア',
	'UserCountry_country_sz' => 'スワジランド',
	'UserCountry_country_ta' => 'トリスタン・ダ・クーニャ',
	'UserCountry_country_tc' => 'タークス・カイコス諸島',
	'UserCountry_country_td' => 'チャド',
	'UserCountry_country_tf' => 'フランス領南方・南極地域',
	'UserCountry_country_tg' => 'トーゴ',
	'UserCountry_country_th' => 'タイ',
	'UserCountry_country_tj' => 'タジキスタン',
	'UserCountry_country_tk' => 'トケラウ（ニュージーランド領）',
	'UserCountry_country_tl' => '東ティモール（インドネシア領）',
	'UserCountry_country_tm' => 'トルクメニスタン',
	'UserCountry_country_tn' => 'チュニジア',
	'UserCountry_country_to' => 'トンガ',
	'UserCountry_country_tp' => '東ティモール（旧ドメイン）',
	'UserCountry_country_tr' => 'トルコ',
	'UserCountry_country_tt' => 'トリニダードトバゴ',
	'UserCountry_country_tv' => 'ツバル',
	'UserCountry_country_tw' => '台湾',
	'UserCountry_country_tz' => 'タンザニア',
	'UserCountry_country_ua' => 'ウクライナ',
	'UserCountry_country_ug' => 'ウガンダ',
	'UserCountry_country_uk' => 'イギリス',
	'UserCountry_country_um' => '太平洋諸島（アメリカ領）',
	'UserCountry_country_us' => 'アメリカ合衆国',
	'UserCountry_country_uy' => 'ウルグアイ',
	'UserCountry_country_uz' => 'ウズベキスタン',
	'UserCountry_country_va' => 'バチカン市国',
	'UserCountry_country_vc' => 'セントビンセント・グレナディーン',
	'UserCountry_country_ve' => 'ベネズエラ',
	'UserCountry_country_vg' => 'ヴァージン諸島（イギリス領）',
	'UserCountry_country_vi' => 'ヴァージン諸島（アメリカ領）',
	'UserCountry_country_vn' => 'ベトナム',
	'UserCountry_country_vu' => 'バヌアツ',
	'UserCountry_country_wf' => 'ウォリス・フツナ（フランス領）',
	'UserCountry_country_ws' => 'サモア',
	'UserCountry_country_ye' => 'イエメン',
	'UserCountry_country_yt' => 'マヨット（フランス領）',
	'UserCountry_country_yu' => '旧ユーゴスラビア',
	'UserCountry_country_za' => '南アフリカ',
	'UserCountry_country_zm' => 'ザンビア',
	'UserCountry_country_zr' => '旧ザイール',
	'UserCountry_country_zw' => 'ジンバブエ',
	'UserCountry_country_a1' => '匿名プロキシ',
	'UserCountry_country_a2' => '衛星プロバイダ',
	'UserCountry_country_ap' => 'アジア太平洋諸国',
	'UserCountry_country_o1' => 'その他の国',
	'UserCountry_continent_eur' => 'ヨーロッパ',
	'UserCountry_continent_afr' => 'アフリカ',
	'UserCountry_continent_ant' => '南極',
	'UserCountry_continent_asi' => 'アジア',
	'UserCountry_continent_amn' => '北アメリカ',
	'UserCountry_continent_amc' => '中央アメリカ',
	'UserCountry_continent_ams' => '南アメリカ',
	'UserCountry_continent_oce' => 'オセアニア',
	'UserCountryMap_map' => '地図',
	'UserCountryMap_worldMap' => '世界地図',
	'UserCountryMap_toggleFullscreen' => 'フルスクリーンに切り替える',
	'UserSettings_PluginDescription' => '各種ユーザー設定（ブラウザ、ブラウザファミリー、オペレーティングシステム、プラグイン、解像度、全般設定）をリポートします。',
	'UserSettings_VisitorSettings' => 'ビジターの環境',
	'UserSettings_BrowserFamilies' => 'ブラウザファミリー',
	'UserSettings_Browsers' => 'ブラウザ',
	'UserSettings_Plugins' => 'プラグイン',
	'UserSettings_Configurations' => '環境設定',
	'UserSettings_OperatingSystems' => 'オペレーティングシステム',
	'UserSettings_Resolutions' => '解像度',
	'UserSettings_WideScreen' => 'ワイド画面',
	'UserSettings_ColumnBrowserFamily' => 'ブラウザファミリー',
	'UserSettings_ColumnBrowser' => 'ブラウザ',
	'UserSettings_ColumnPlugin' => 'プラグイン',
	'UserSettings_ColumnConfiguration' => '環境設定',
	'UserSettings_ColumnOperatingSystem' => 'オペレーティングシステム',
	'UserSettings_ColumnResolution' => '解像度',
	'UserSettings_ColumnTypeOfScreen' => '画面タイプ',
	'UserSettings_WidgetResolutions' => '画面解像度',
	'UserSettings_WidgetBrowsers' => 'ブラウザ',
	'UserSettings_WidgetPlugins' => 'プラグイン一覧',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => '注意： Internet Explorer ではプラグインの検出が動作しません。 このリポートは、非 IE ブラウザのみに基づきます。',
	'UserSettings_WidgetWidescreen' => 'ノーマル / ワイド画面',
	'UserSettings_WidgetBrowserFamilies' => 'ファミリー単位のブラウザ',
	'UserSettings_WidgetOperatingSystems' => 'オペレーティングシステム',
	'UserSettings_WidgetGlobalVisitors' => 'ビジターの全般的な環境設定',
	'UserSettings_SubmenuSettings' => 'システム構成',
	'UsersManager_PluginDescription' => 'Piwik でのユーザー管理は、新規ユーザーの追加、既存ユーザーの編集、パーミッションの更新を行うことができます。 また、すべての動作は API を通じて利用することができます。',
	'UsersManager_UsersManagement' => 'ユーザーの管理',
	'UsersManager_UsersManagementMainDescription' => '新規ユーザーの作成や、既存ユーザーを更新します。 その後、上でユーザーのパーミッションの設定ができます。',
	'UsersManager_ManageAccess' => '権限の管理',
	'UsersManager_MainDescription' => '各ユーザーのウェブサイト上での Piwik 権限を決定します。  また、全ウェブサイトのパーミッションを一度に設定することもできます。',
	'UsersManager_Sites' => 'ウェブサイト',
	'UsersManager_AllWebsites' => '全ウェブサイト',
	'UsersManager_ApplyToAllWebsites' => '全ウェブサイトに適用',
	'UsersManager_User' => 'ユーザー',
	'UsersManager_PrivNone' => '権限なし',
	'UsersManager_PrivView' => '表示',
	'UsersManager_PrivAdmin' => '管理',
	'UsersManager_ChangeAllConfirm' => '本当に全ウェブサイトでの \'%s\' のパーミッションを変更しますか？',
	'UsersManager_Password' => 'パスワード',
	'UsersManager_Email' => 'メール',
	'UsersManager_Alias' => 'エイリアス',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'スーパーユーザーのエイリアスを変更することはできません。',
	'UsersManager_ReportToLoadByDefault' => 'デフォルトで読み込むリポート',
	'UsersManager_ReportDateToLoadByDefault' => 'デフォルトで読み込むリポートの日付',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => 'anonymous ユーザー用にデフォルトで読み込むリポートの日付',
	'UsersManager_ExcludeVisitsViaCookie' => '自分自身のビジットを除外（Cookie 使用）',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%sあなた自身のビジットは、%s の Piwik に無視されています%s（ブラウザで Piwik 無視用の Cookie が見つかりました）。',
	'UsersManager_YourVisitsAreNotIgnored' => '%sあなた自身のビジットは、Piwik に無視されていません%s（ブラウザで Piwik 無視用の Cookie が見つかりませんでした）。',
	'UsersManager_ClickHereToDeleteTheCookie' => 'Cookie を削除し、Piwik があなた自身のビジットもトラッキングするようにするには、ここをクリックします。',
	'UsersManager_ClickHereToSetTheCookieOnDomain' => '%s の Piwik にトラッキングされるウェブサイトでの、あなた自身のビジットを除外するための Cookie をセットするには、ここをクリックします。',
	'UsersManager_Edit' => '編集',
	'UsersManager_AddUser' => '新しいユーザーの追加',
	'UsersManager_MenuUsers' => 'ユーザー',
	'UsersManager_MenuUserSettings' => 'ユーザーの設定',
	'UsersManager_MenuAnonymousUserSettings' => 'anonymous ユーザーの設定',
	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => '注意： anonymous ユーザーがアクセスできるウェブサイトがないため、次の設定は使用されません。',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => '未ログインのユーザーが Piwik にアクセスした際に表示する画面',
	'UsersManager_ChangePassword' => 'パスワードの変更',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'パスワードを変更したい場合は、新しいパスワードを入力します。 変更しない場合は、空欄のままにします。',
	'UsersManager_TypeYourPasswordAgain' => '新しいパスワードを再入力します。',
	'UsersManager_TheLoginScreen' => 'ログイン画面',
	'UsersManager_DeleteConfirm_js' => '本当にユーザー %s を削除しますか？',
	'UsersManager_YourUsernameCannotBeChanged' => 'あなたのユーザー名を変更することはできません。',
	'UsersManager_ExceptionLoginExists' => 'ユーザー名 \'%s\' はすでに存在します。',
	'UsersManager_ExceptionEmailExists' => 'メールアドレスが \'%s\' のユーザーはすでに存在します。',
	'UsersManager_ExceptionInvalidLoginFormat' => 'ユーザー名は、英数字、\'_\'（アンダーバー）、\'-\'（ハイフン）、\'@\'（アットマーク）のみを含む、%1$s～%2$s 文字である必要があります。',
	'UsersManager_ExceptionInvalidEmail' => 'メールアドレスが有効な形式ではありません。',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'ユーザー \'%s\' は存在しないため、削除することができません。',
	'UsersManager_ExceptionAdminAnonymous' => '\'anonymous\' ユーザーに \'管理\' 権限を与えることはできません。',
	'UsersManager_ExceptionEditAnonymous' => 'anonymous ユーザーは、Piwik がログインしていないユーザーを定義するために使用するため、編集や削除はできません。 例えば、\'anonymous\' ユーザーに \'表示\' 権限を与えることによって、統計をパブリックにすることができます。',
	'UsersManager_ExceptionSuperUser' => '要求されたユーザーはスーパーユーザーであり、API 経由で照会、編集、削除することはできません。 Piwik 設定ファイルで、スーパーユーザーの詳細を手作業で編集することができます。',
	'UsersManager_ExceptionUserDoesNotExist' => 'ユーザー \'%s\' は存在しません。',
	'UsersManager_ExceptionAccessValues' => 'パラメータ access は、次の値のいずれかを持つ必要があります： [ %s ]',
	'UsersManager_ExceptionPasswordMD5HashExpected' => 'UsersManager.getTokenAuth は、MD5 ハッシュ値のパスワード（32文字長の文字列）を想定しています。 このメソッドをコールする前に、パスワードに対して md5() 関数をコールしてください。',
	'VisitFrequency_PluginDescription' => 'リピーターと新規ビジターの対比に関するさまざまな統計をリポートします。',
	'VisitFrequency_Evolution' => '一定期間の推移',
	'VisitFrequency_ColumnReturningVisits' => 'リピートビジット',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'リピートビジットによるアクション',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => 'リピートビジットの平均ビジット継続時間（秒単位）',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'リピートビジットのバウンス率',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => 'リピートビジット単位の平均アクション数',
	'VisitFrequency_ReturnVisits' => '%s リピートビジット',
	'VisitFrequency_ReturnActions' => '%s リピートビジットによるアクション数',
	'VisitFrequency_ReturnAvgActions' => '%s リピートビジット単位のアクション数',
	'VisitFrequency_ReturnAverageVisitDuration' => '%s リピートビジットの平均ビジット継続時間',
	'VisitFrequency_ReturnBounceRate' => '%s バウンスしたリピートビジット（1ページを表示後にウェブサイトを離れた）',
	'VisitFrequency_WidgetOverview' => '頻度の概観',
	'VisitFrequency_WidgetGraphReturning' => 'リピートビジットのグラフ',
	'VisitFrequency_SubmenuFrequency' => '頻度',
	'VisitorGenerator_PluginDescription' => '偽のビジットを作成するプラグインです。 Piwik のユーザーや開発者が、Piwik リポートに偽のデータを生成する簡単な方法として使用することができます。',
	'VisitorGenerator_VisitorGenerator' => 'ビジタージェネレータ',
	'VisitorGenerator_Warning' => 'Piwik データベースに記録される偽のビジットを生成しようとしています。',
	'VisitorGenerator_NotReversible' => 'Piwik のログからこれらのビジットを%s容易に削除することはできません%s。',
	'VisitorGenerator_AreYouSure' => '本当に偽のビジットを生成しますか？',
	'VisitorGenerator_ChoiceYes' => 'はい、お願いします！',
	'VisitorGenerator_Submit' => '実行',
	'VisitorGenerator_SelectWebsite' => 'ウェブサイトの選択',
	'VisitorGenerator_NbRequestsPerSec' => '秒単位のリクエスト数',
	'VisitorGenerator_DaysToCompute' => '算出する日数',
	'VisitorInterest_PluginDescription' => 'ビジターの興味（表示したページ数、ウェブサイト滞在時間）についてリポートします。',
	'VisitorInterest_VisitsPerDuration' => 'ビジット継続時間単位のビジット',
	'VisitorInterest_VisitsPerNbOfPages' => 'ページ数単位のビジット',
	'VisitorInterest_ColumnVisitDuration' => 'ビジットの継続時間',
	'VisitorInterest_ColumnPagesPerVisit' => 'ビジット単位のページ数',
	'VisitorInterest_WidgetLengths' => 'ビジットの長さ',
	'VisitorInterest_WidgetPages' => 'ビジット単位のページ数',
	'VisitorInterest_Engagement' => '利用状況',
	'VisitorInterest_PlusXMin' => '%s 分',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s 分',
	'VisitorInterest_OnePage' => '1 ページ',
	'VisitorInterest_NPages' => '%s ページ',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$s 秒',
	'VisitsSummary_PluginDescription' => '全体的な解析数（ビジット、ユニークビジター数、アクション数、バウンス率等）をリポートします。',
	'VisitsSummary_VisitsSummary' => 'ビジットの概要',
	'VisitsSummary_NbVisits' => '%s ビジット数',
	'VisitsSummary_NbUniqueVisitors' => '%s ユニークビジター数',
	'VisitsSummary_NbActionsDescription' => '%s アクション（ページビュー、ダウンロード、外部リンク）',
	'VisitsSummary_AverageVisitDuration' => '%s ビジットの平均持続時間',
	'VisitsSummary_MaxNbActions' => '%s 1ビジットでの最大アクション数',
	'VisitsSummary_NbActionsPerVisit' => '%s ビジット単位のアクション数',
	'VisitsSummary_NbVisitsBounced' => '%s バウンスしたビジット（1ページを表示後にウェブサイトを離れた）',
	'VisitsSummary_EvolutionOverLastPeriods' => '直近の %s にわたる推移',
	'VisitsSummary_GenerateTime' => 'ページ生成時間 %s 秒',
	'VisitsSummary_GenerateQueries' => '実行されたクエリ %s',
	'VisitsSummary_WidgetLastVisits' => '最終ビジットのグラフ',
	'VisitsSummary_WidgetVisits' => 'ビジットの概観',
	'VisitsSummary_WidgetLastVisitors' => '最終ユニークビジターのグラフ',
	'VisitsSummary_WidgetOverviewGraph' => 'グラフ付き概観',
	'VisitsSummary_SubmenuOverview' => '概観',
	'VisitTime_PluginDescription' => 'ローカルタイムとサーバータイムでリポートします。 サーバタイムの情報は、ウェブサイトのメンテナンスを予定するのに便利です。',
	'VisitTime_LocalTime' => 'ローカルタイム単位のビジット',
	'VisitTime_ServerTime' => 'サーバタイム単位のビジット',
	'VisitTime_ColumnServerTime' => 'サーバタイム',
	'VisitTime_ColumnLocalTime' => 'ローカルタイム',
	'VisitTime_WidgetLocalTime' => 'ローカルタイム単位のビジット',
	'VisitTime_WidgetServerTime' => 'サーバタイム単位のビジット',
	'VisitTime_SubmenuTimes' => '時間',
	'VisitTime_NHour' => '%s時',
	'Widgetize_PluginDescription' => 'あなたのブログ、ウェブサイト、Igoogle、Netvibes 等に、任意の Piwik ウィジェットをとても簡単にエクスポートできるようにします。',
	'PDFReports_EmailReports' => 'メールリポート',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_SendReportNow' => 'ただちにリポートを送信',
	'PDFReports_EmailSchedule' => 'メールスケジュール',
	'PDFReports_SendReportTo' => 'リポートの送信先',
	'PDFReports_SentToMe' => '自分宛に送信',
	'PDFReports_WeeklyScheduleHelp' => '週間スケジュール： リポートは毎週月曜日に送信されます。',
	'PDFReports_MonthlyScheduleHelp' => '月間スケジュール： リポートは毎月1日に送信されます。',
	'PDFReports_AlsoSendReportToTheseEmails' => '以下のメールアドレスにも送信（1行ごとに1アドレス）',
	'PDFReports_PiwikReports' => 'Piwik リポート',
	'PDFReports_EmailHello' => 'こんにちは、',
	'PDFReports_PleaseFindAttachedFile' => '添付ファイルから %2$s の %1$s リポートを見つけてください。',
);
